@@ -117,6 +117,11 @@ class Tile:
         """Return the name."""
         return self._tile_data["name"]
 
+    @property
+    def ring_state(self) -> str:
+        """Return the ring state."""
+        return self._tile_data["last_tile_state"]["ring_state"]
+
     @property
     def uuid(self) -> str:
         """Return the UUID."""
@@ -127,6 +132,11 @@ class Tile:
         """Return whether the Tile is visible."""
         return self._tile_data["visible"]
 
+    @property
+    def voip_state(self) -> str:
+        """Return the VoIP state."""
+        return self._tile_data["last_tile_state"]["voip_state"]
+
     def _async_save_new_data(self, data: dict) -> None:
         """Save new Tile data in this object."""
         try:
